Module Module1

    Dim mstrFileDemoRoot As String = "E:"  '<-- Replace "E" with the letter of your flash drive.
    Dim mastrFiles As Collections.ObjectModel.ReadOnlyCollection(Of String)
    Dim mstrFileX As String
    Dim mobjFileInfo As System.IO.FileInfo

    Sub Main()

        ' First make sure we are dealing with a removable drive (i.e. a flash drive). 
        ' We don't want to be running this on a hard drive.
        If Not DriveIsRemovable(mstrFileDemoRoot) Then
            Console.WriteLine("A removable drive must be used for this program.")
            Console.WriteLine("Press Enter to close this window.")
            Console.ReadLine()
            End
        End If

        With My.Computer.FileSystem

            ' Make the top-level subdirectories below the file demo root with
            ' the CreateDirectory method of the System.IO Directory class ...

            .CreateDirectory(mstrFileDemoRoot & "\SYSTEM")
            .CreateDirectory(mstrFileDemoRoot & "\COMMAND")
            .CreateDirectory(mstrFileDemoRoot & "\EXECUTE")
            .CreateDirectory(mstrFileDemoRoot & "\INITIAL")
            .CreateDirectory(mstrFileDemoRoot & "\TEXT")
            .CreateDirectory(mstrFileDemoRoot & "\WRITE")

            Console.WriteLine("Top-level directories have been made.")

            ' Use the GetFiles method of the My.Computer.FileSystem class to get a list of
            ' all the files in the file demo root. (The list is returned as a read-only
            ' collection of strings, and each filename in the collection will contain the 
            ' full path and filename.)

            mastrFiles = .GetFiles(mstrFileDemoRoot)

            ' Loop through the collection of files using a For/Each loop ...
            For Each mstrFileX In mastrFiles
                ' Create a "FileInfo" object for the current file (mstrFileX) that
                ' we are processing. Using this will make it easy to extract the extension
                ' and filename portion of the current file being processed.
                mobjFileInfo = .GetFileInfo(mstrFileX)
                ' The Select Case structure below tests the extension of the current file
                ' and moves that file to the designated sub. The moves are accomplished
                ' with the MoveFile method of the My.Computer.FileSystem File class ...
                Select Case mobjFileInfo.Extension.ToUpper
                    Case ".SYS"
                        .MoveFile(mstrFileX, mstrFileDemoRoot & "\SYSTEM\" & mobjFileInfo.Name)
                    Case ".COM"
                        .MoveFile(mstrFileX, mstrFileDemoRoot & "\COMMAND\" & mobjFileInfo.Name)
                    Case ".EXE"
                        .MoveFile(mstrFileX, mstrFileDemoRoot & "\EXECUTE\" & mobjFileInfo.Name)
                    Case ".INI"
                        .MoveFile(mstrFileX, mstrFileDemoRoot & "\INITIAL\" & mobjFileInfo.Name)
                    Case ".TXT"
                        .MoveFile(mstrFileX, mstrFileDemoRoot & "\TEXT\" & mobjFileInfo.Name)
                    Case ".WRI"
                        .MoveFile(mstrFileX, mstrFileDemoRoot & "\WRITE\" & mobjFileInfo.Name)
                End Select
            Next

            Console.WriteLine("Files have been moved from the root to their respective top-level directories.")

            ' Create the EXE_INI subdirectory below the SYSTEM subdirectory ...
            .CreateDirectory(mstrFileDemoRoot & "\SYSTEM\EXE_INI")
            Console.WriteLine("Second-level directory for EXE and INI files has been made.")
            ' Get the list of files in the EXECUTE subdirectory and copy them over 
            ' the SYSTEM\EXE_INI sub. The copies are accomplished with the CopyFile method 
            ' of the My.Computer.FileSystem File class ...
            mastrFiles = .GetFiles(mstrFileDemoRoot & "\EXECUTE")
            For Each mstrFileX In mastrFiles
                mobjFileInfo = .GetFileInfo(mstrFileX)
                .CopyFile(mstrFileX, mstrFileDemoRoot & "\SYSTEM\EXE_INI\" & mobjFileInfo.Name)
            Next
            ' Get the list of files in the INITIAL subdirectory and copy them over 
            ' the SYSTEM\EXE_INI sub. The copies are accomplished with the CopyFile method 
            ' of the My.Computer.FileSystem File class ...
            mastrFiles = .GetFiles(mstrFileDemoRoot & "\INITIAL")
            For Each mstrFileX In mastrFiles
                mobjFileInfo = .GetFileInfo(mstrFileX)
                .CopyFile(mstrFileX, mstrFileDemoRoot & "\SYSTEM\EXE_INI\" & mobjFileInfo.Name)
            Next
            Console.WriteLine("Files have been copied to EXE_INI .")

            ' Create the TXT_WRI subdirectory below the SYSTEM subdirectory ...
            .CreateDirectory(mstrFileDemoRoot & "\INITIAL\TXT_WRI")
            Console.WriteLine("Second-level directory for TXT and WRI files has been made.")
            ' Get the list of files in the TEXT subdirectory and copy them over 
            ' the INITIAL\TXT_WRI sub. The copies are accomplished with the CopyFile method 
            ' of the My.Computer.FileSystem File class ...
            mastrFiles = .GetFiles(mstrFileDemoRoot & "\TEXT")
            For Each mstrFileX In mastrFiles
                mobjFileInfo = New System.IO.FileInfo(mstrFileX)
                .CopyFile(mstrFileX, mstrFileDemoRoot & "\INITIAL\TXT_WRI\" & mobjFileInfo.Name)
            Next
            ' Get the list of files in the WRITE subdirectory and copy them over 
            ' the INITIAL\TXT_WRI sub. The copies are accomplished with the CopyFile method 
            ' of the My.Computer.FileSystem File class ...
            mastrFiles = .GetFiles(mstrFileDemoRoot & "\WRITE")
            For Each mstrFileX In mastrFiles
                mobjFileInfo = New System.IO.FileInfo(mstrFileX)
                .CopyFile(mstrFileX, mstrFileDemoRoot & "\INITIAL\TXT_WRI\" & mobjFileInfo.Name)
            Next
            Console.WriteLine("Files have been copied to TXT_WRI .")

        End With

        ' The first part of the exercise is complete. You may want to inspect the contents
        ' of the file demo root directory before pressing Enter to reset.
        Console.WriteLine("")
        Console.WriteLine("The first part of the exercise is complete.")
        Console.WriteLine("You may wish to inspect the file demo directory")
        Console.WriteLine("to see the results before resetting.")
        Console.WriteLine("Press Enter to reset.")
        Console.ReadLine()
        Console.WriteLine("")

        ' The following group of statements cause the file demo root directory to return
        ' to its original state - all files are moved back to the root, and the individual
        ' subdirectories are deleted. This is done in a Sub called "MoveFilesBackToRoot", 
        ' which is called for each of the subdirectories:
        MoveFilesBackToRoot("SYSTEM")
        MoveFilesBackToRoot("COMMAND")
        MoveFilesBackToRoot("EXECUTE")
        MoveFilesBackToRoot("INITIAL")
        MoveFilesBackToRoot("TEXT")
        MoveFilesBackToRoot("WRITE")

        Console.WriteLine("")
        Console.WriteLine("The second part of the exercise is complete.")
        Console.WriteLine("Press Enter to close this window.")
        Console.ReadLine()

    End Sub

    Private Sub MoveFilesBackToRoot(ByVal pstrDirectory As String)

        With My.Computer.FileSystem

            ' Use the GetFiles method of the My.Computer.FileSystem class to get a list of
            ' all the files in the passed-in subdirectory of the file demo root directory.
            mastrFiles = .GetFiles(mstrFileDemoRoot & "\" & pstrDirectory)

            ' Move each file in the specified subdirectory back to the file demo root.
            For Each mstrFileX In mastrFiles
                mobjFileInfo = New System.IO.FileInfo(mstrFileX)
                .MoveFile(mstrFileX, mstrFileDemoRoot & "\" & mobjFileInfo.Name)
            Next

            ' Delete the individual subdirectory. 
            .DeleteDirectory(mstrFileDemoRoot & "\" & pstrDirectory, _
                             FileIO.DeleteDirectoryOption.DeleteAllContents)

            Console.WriteLine(pstrDirectory & " directory has been cleared; files moved back to root.")

        End With

    End Sub

    ' Helper function below to ensure a removable drive is being used
    Private Function DriveIsRemovable(ByVal pstrDriveLetter As String) As Boolean

        Dim allDrives() As DriveInfo = DriveInfo.GetDrives()
        Dim d As DriveInfo
        For Each d In allDrives
            If d.DriveType = DriveType.Removable And d.Name.ToUpper.StartsWith(pstrDriveLetter.ToUpper) Then
                Return True
            End If
        Next

        Return False

    End Function

End Module
